@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import List, Optional, Union
 
 import pandas as pd
 
@@ -11,14 +11,18 @@ from .utils.units_docstring import list_units_docstring
 @pipeline_function
 @list_units_docstring
 def convert(
-    data: pd.DataFrame, columns: List[str], from_unit: str, to_unit: Optional[str] = None, inplace: bool = False
-) -> pd.DataFrame:
+    data: Union[float, int, pd.DataFrame],
+    from_unit: str,
+    to_unit: Optional[str] = None,
+    columns: Optional[List] = None,
+    inplace: bool = False,
+) -> Union[float, int, pd.DataFrame]:
     """
     Convert specified columns in data from given unit to another unit.
     
     Args:
-        data (pd.DataFrame): Data to be converted.
-        columns (List[str]): List of columns to convert.
+        data (float, int, pd.DataFrame): Data to be converted.
+        columns (List[str], optional): List of columns to convert.
         from_unit (str): Current unit of the specified columns.
         to_unit (str, optional): Specifies which unit the columns should be converted to.
             Default is to convert to SI units.
@@ -29,9 +33,12 @@ def convert(
     """  # noqa
     f = _UNITS.get_converter(from_unit=from_unit, to_unit=to_unit)
 
-    if not inplace:
-        data = data.copy(deep=True)
+    if isinstance(data, pd.DataFrame):
+        if not inplace:
+            data = data.copy(deep=True)
 
-    data[columns] = f(data[columns])
+        data[columns] = f(data[columns])
+    else:
+        data = f(data)
 
     return data
